@@ -15,7 +15,6 @@ struct Applet
   char * icon_file;
 };
 
-/* When translation will be implemented...*/
 #define _(x) gettext(x)
 
 
@@ -24,7 +23,7 @@ void printlog(GtkWidget *textview, gchar *str);
 /* Return 1 if a file exists & can be read, 0 otherwise.*/
 int file_exists (char *fn);
 GtkWidget *make_menu_from_dir(char *path, int(*entrytest)(char* path), char *current);
-GList *make_items_from_dir(char *path);
+GList *make_items_from_dir(char *path, char *filter);
 
 // I just want to get a file !
 void ask_user_a_file(char *path, char *prompt,
